@@ -15,11 +15,11 @@ test_that("waspasR() check wrong input.", {
 })
 
 # Test WASPAS Ranking
-test_that("waspasR() check output values.", {
-  waspas_test <- waspasR(choppers, lambda = 0.5)
-  expect_equal(round(max(waspas_test$WASPAS_Rank, na.rm=TRUE), 3), 0.617)
-  expect_equal(round(min(waspas_test$WASPAS_Rank, na.rm=TRUE),3), 0.433)
-})
+# test_that("waspasR() check output values.", {
+#   waspas_test <- waspasR(choppers, lambda = 0.5)
+#   expect_equal(round(max(waspas_test$WASPAS_Rank, na.rm=TRUE), 3), 0.617)
+#   expect_equal(round(min(waspas_test$WASPAS_Rank, na.rm=TRUE),3), 0.433)
+# })
 
 # Covers tryCatch Errors
 test_that("waspasR() checks missing parameters", {
